@@ -15,7 +15,7 @@ import sys
 
 # Importar módulos propios
 from vacancy_predictor.core.ml_components import DataProcessor, ModelTrainer, Visualizer
-from vacancy_predictor.gui.tabs.lammps_tab import LAMMPSTab
+
 
 # Importar tabs originales - estos necesitarías crear/adaptar desde tu código original
 from vacancy_predictor.gui.tabs.data_tabs import DataTab
@@ -128,8 +128,8 @@ class VacancyPredictorGUI:
         self.notebook.add(self.feature_selector_tab.frame, text="⚙️ Feature Selector")
         
         # Nuevo tab LAMMPS
-        self.lammps_tab = LAMMPSTab(self.notebook, self.on_lammps_data_loaded)
-        self.notebook.add(self.lammps_tab.frame, text="⚛️ LAMMPS")
+        #self.lammps_tab = LAMMPSTab(self.notebook, self.on_lammps_data_loaded)
+        #self.notebook.add(self.lammps_tab.frame, text="⚛️ LAMMPS")
 
     def create_status_bar(self):
         """Crear barra de estado"""
